{
  pkgs,
  utilPkgs,
}:
pkgs.writeShellScriptBin "create-gitlab-ci-config" ''
  source ${utilPkgs.utils-sh}
  source ${utilPkgs.print-sh}

  force=0

  while [[ $# -gt 0 ]]; do
    case $1 in
      --force)
        force=1
        shift
        ;;
      *)
        shift
        ;;
    esac
  done

  # Set cwd to the project root path.
  cwd=$(get_project_root)

  # Abort if .gitlab-ci.yml exists and force is disabled.
  if [ $force -eq 0 ] && [ -f "$cwd/.gitlab-ci.yml" ]; then
    print_banner \
      --error \
      --title="File already exists" \
      "A .gitlab-ci.yml file already exists in your project!" \
      "" \
      "Run this script with --force to override the file."

    exit 1
  fi

  dev_shells=$(nix eval --json '.#devShells.x86_64-linux' | ${pkgs.jq}/bin/jq -r 'keys[]' | ${pkgs.gnugrep}/bin/grep -v default | ${pkgs.gawk}/bin/awk -v ORS=', ' '{print $1}' | ${pkgs.gnused}/bin/sed 's/, $//')

  sed "s/___DEVSHELLS___/$dev_shells/" ${../../lib/gitlab-ci.yml} > "$cwd/.gitlab-ci.yml"

  print_banner \
    --success \
    --title="File created" \
    "A .gitlab-ci.yml has been created!" \
    "" \
    "CI is run for the following dev shells:" \
    "$dev_shells"
''
