{
  pkgs,
  utilPkgs,
}:
# Shell script to setup the devenv composer json file.
#
# Requires the name of the devenv specific composer json file
# to be set in the $COMPOSER env var.
#
# All contents of the module's `composer.json` file are merged
# into the devenv comopser json file.
pkgs.writeShellScript "setup-composer-json.sh" ''
  source ${utilPkgs.utils-sh}
  source ${utilPkgs.git-sh}

  # Set cwd to the project root path.
  cwd=$(get_project_root)

  # Sanity check.
  if [ -z "$COMPOSER" ]; then
    echo "COMPOSER env var not set!"
    exit 1
  fi

  # Generate lockfile name.
  lockfile=$(echo "$COMPOSER" | sed 's/.json/.lock/')

  # Remove existing ephemeral composer files.
  if [ -f "$COMPOSER" ]; then
    rm "$COMPOSER"
  fi
  if [ -f "$lockfile" ]; then
    rm "$lockfile"
  fi

  # Evaluate the PHP script to get the default contents for the
  # devenv composer json file.
  default_composer_json=$(SETUP_CWD="$cwd" php ${../../lib/create-composer-json.php})

  # Merge all composer.json files together in the correct order and
  # create the final composer.devenv.json file.
  #
  # If an override file exists, include it in the merging.
  if [ -f "$cwd/composer.devenv-override.json" ]; then
    echo "$default_composer_json" \
      | ${pkgs.jq}/bin/jq \
        -s '.[0] * .[1] * .[2]' \
        - composer.devenv-override.json composer.json \
      | ${pkgs.jq}/bin/jq 'del(..|select((. == null) or (. == "") or (. == []) ))' \
      | ${pkgs.jq}/bin/jq 'del(..|select(. == {}))' > "$COMPOSER"
  # Otherwise, just merge the default with the actual project
  # composer.json
  else
    echo "$default_composer_json" \
      | ${pkgs.jq}/bin/jq \
        -s '.[0] * .[1]' \
        - composer.json \
      | ${pkgs.jq}/bin/jq 'del(..|select((. == null) or (. == "") or (. == []) ))' \
      | ${pkgs.jq}/bin/jq 'del(..|select(. == {}))' > "$COMPOSER"
  fi

  # Update .gitignore.
  add_to_gitignore --cwd="$cwd" "/$COMPOSER"
  add_to_gitignore --cwd="$cwd" "/$lockfile"
  add_to_gitignore --cwd="$cwd" "/vendor/"
  add_to_gitignore --cwd="$cwd" "/$WEB_ROOT/"
''
