{
  pkgs,
  utilPkgs,
}: let
  setup-composer-json = import ./setup-composer-json.nix {
    inherit pkgs utilPkgs;
  };
  setup-project = import ./setup-project.nix {
    inherit pkgs utilPkgs;
  };
in
  pkgs.writeShellScriptBin "setup-drupal" ''
    source ${utilPkgs.utils-sh}
    source ${utilPkgs.print-sh}

    cwd=$(get_project_root)

    # Check that a composer.json file exists in the project root folder.
    if [ ! -f "$cwd/composer.json" ]; then
      print_banner \
        --error \
        --title="Invalid directory!" \
        "No composer.json file has been found in the project root." \
        "" \
        "Is this a drupal module folder?"

      exit 1
    fi

    # Make sure the $COMPOSER env var is set.
    if [ -z "$COMPOSER" ]; then
      print_banner \
        --error \
        --title="Missing variables!" \
        "No COMPOSER env variable is set!"
      exit 1
    fi

    # Prepare composer json.
    print_banner \
      --info \
      --title="Setting up local drupal" \
      "> Creating $COMPOSER file" \
      ">   Installing Drupal $DRUPAL_CORE_CONSTRAINT" \
      ">   Via PHP $(echo '<?php echo phpversion();' | php)" \
      "> Setting up module folder in $WEB_ROOT" \
      "> Linking module files from project root to module folder"

    ${setup-composer-json}

    # Setup project.
    if [[ -z "$COMPOSER_PLUGIN_PREPARE" ]] || [[ "$COMPOSER_PLUGIN_PREPARE" != "true" ]] ; then
      ${setup-project}
    fi

    composer update --prefer-stable --no-interaction --no-progress
    # If composer install failed.
    if [ $? -ne 0 ]; then
      print_banner \
        --error \
        --title="Setup failed" \
        "Could not install Drupal and/or dependencies." \
        "See logs above for more details."
      exit 1
    fi

    printf "\n"

    # Print status info via
    drush_status=$($cwd/vendor/bin/drush status)
    drupal_version=$(echo "$drush_status" | grep 'Drupal version' --color=no)
    php_version=$(echo "$drush_status" | grep 'PHP version' --color=no)
    drush_version=$(echo "$drush_status" | grep 'Drush version' --color=no)
    sqlite_version=$(php -r 'print_r(SQLite3::version()["versionString"]);')

    print_banner \
      --success \
      --title="Setup complete" \
      "$drupal_version" \
      "$php_version" \
      "$drush_version" \
      "SQLite version : $sqlite_version"
  ''
