{
  pkgs,
  utilPkgs,
}:
# Shell script to setup the project structure.
#
# Requires the name of the devenv specific composer json file
# to be set in the $COMPOSER env var.
#
# The drupal web root can be configured via $WEB_ROOT env var.
#
# Creates a folder for this module in the $WEB_ROOT. The name
# is extracted from the *.info.yml file.
# All files and directories in the module dir that are not git ignored
# are symlinked into the drupal installation module folder.
pkgs.writeShellScript "setup-project.sh" ''
  source ${utilPkgs.utils-sh}
  source ${utilPkgs.env-sh}

  # Set cwd to the project root path.
  cwd=$(get_project_root)

  # Set webroot from env, use default otherwise.
  web_root=$(get_env_default "WEB_ROOT" "web")

  # Extract the project name from the composer file.
  project_name=$(cat "$cwd/$COMPOSER" | ${pkgs.jq}/bin/jq '.name' -r | cut -d'/' -f2)

  # Define the module root in the drupal installation.
  # Removes the folder if it already exists.
  module_root="$cwd/$web_root/modules/custom/$project_name"
  if [ -d "$module_root" ]; then
    rm -r "$module_root"
  fi

  # Create empty module folder in drupal dir.
  mkdir -p "$module_root"

  # Get all files and directories in the $cwd (including hidden) that are
  # not git ignored, and exlude .git directory and the composer override json file.
  files=$(${pkgs.fd}/bin/fd -d1 -H -E '.git' -E 'composer.*-override.json' . "$cwd")

  # Link all files into the just created module folder in
  # the drupal directory.
  for file in $files; do
    fname=$(basename "$file")
    relpath=$(${pkgs.toybox}/bin/realpath -m "$file" --relative-to "$module_root")

    ln -s "$relpath" "$module_root/$fname"
  done
''
